#include "ParamRange.h"
#include "Utils.h"

namespace ffgl
{

ParamRange::ParamRange( const std::string& name, float defaultValue, const RangeStruct range ) :
	ParamFloat( name, ParameterType::FF_TYPE_STANDARD ),
	range( range )
{
	value = utils::map( defaultValue, range.min, range.max, 0.0f, 1.0f );
	defaultValue = value;
}

ParamRange::ParamRange( const std::string& name, ParameterType type, float defaultValue, const RangeStruct range ) :
	ParamFloat( name, type ),
	range( range )
{
	defaultValue = utils::map( defaultValue, range.min, range.max, 0.0f, 1.0f );
	Reset();
}

const std::string& ParamRange::GetDisplay() const
{
	return std::to_string( GetRealValue() );
}

const RangeStruct ParamRange::GetRange() const
{
	return range;
}

void ParamRange::SetRange(const RangeStruct newRange)
{
	range = newRange;
}

float ParamRange::GetRealValue() const
{
	return utils::map( GetFloatValue(), 0.0, 1.0, range.min, range.max );
}

}//End namespace ffgl